@@ -194,7 +194,6 @@ pub struct InsertOpt {
 }
 
 fn main() -> Result<(), Error> {
-
     let opt = Cli::parse();
 
     let verbose = if opt.quiet {
@@ -253,14 +252,6 @@ fn main() -> Result<(), Error> {
         }
     }
 
-    println!(
-        "Peace for the citizens of Ukraine who fight for their freedom and stand up to oppression. \
-        Peace for the Russian soldier, who does not know why he is shooting at his brothers and \
-        sisters, may he be reunited with his family soon.
-        
-        Peace to 🇺🇦, 🇷🇺 and the world. May sanity prevail.
-    ");
-
     Ok(())
 }
 
